# -*- coding: utf-8 -*-
#
#    copyright (C) 2023 Steffen Rolapp (github@rolapp.de)
#
#    based on ZattooBoxExtended by Daniel Griner (griner.ch@gmail.com) License under GPL
#    based on ZattooBox by Pascal Nançoz (nancpasc@gmail.com) Licence under BSD 2 clause
#
#    This file is part of zattooHiQ
#
#    zattooHiQ is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    zattooHiQ is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with zattooHiQ.  If not, see <http://www.gnu.org/licenses/>.
#

import sys, xbmcgui, xbmc, xbmcaddon
from resources.lib.zattooDB import ZattooDB
from resources.lib.keymap import KeyMap
from resources.lib.tools import *
from resources.lib.directorys import *

#from resources.lib.myplayer import myPlayer

__addon__  = xbmcaddon.Addon()
_zattooDB_ = ZattooDB()
_keymap_   = KeyMap()

if __addon__.getSetting('show_favourites')=='true':_listMode_ ='favourites'
else: _listMode_ ='all'

def router(params):
  # Get the plugin url in plugin:// notation.
  #global __addonuri__ 
  #__addonuri__ = url
  # Get the plugin handle as an integer number.
  #global __addonhandle__
  #__addonhandle__ = int(handle)
  #AddonHandle(__addonhandle__)
  #xbmcgui.Window(10000).setProperty('handle', str(handle))
  
  args = dict(parse_qsl(params))
  debug(args)
  global _listMode_
  if _listMode_ == None: _listMode_='all'

  try:
    channel=_zattooDB_.get_playing()['channel']
    channeltitle=_zattooDB_.get_channeltitle(channel)
    program = _zattooDB_.getPrograms({'index':[channel]}, datetime.datetime.now(), datetime.datetime.now())
  except:pass
  try:
    program=program[0]
  except:pass

  if args:
    action = args['mode']
    xbmcgui.Window(10000).setProperty('ZBElastAction', action)
    
    if action == 'channellist': build_channelsList()
    elif action == 'preview': showPreview()
    elif action == 'previewOSD': showPreview()
    elif action == 'epg': showEpg()
    elif action == 'epgOSD': showEpg()
    elif action == 'recordings': build_recordingsList()
    elif action == 'searchlist': build_searchList()
    elif action == 'selectStartChannel': selectStartChannel()
    elif action == 'editKeyMap': _keymap_.editKeyMap()
    elif action == 'deleteKeyMap': _keymap_.deleteKeyMap()
    #elif action == 'showKeyMap': showkeymap()
    elif action == 'record_l': setup_recording(program['showID'])
    elif action == 'search':
      search = args.get('id','')
      search_show(search)
    elif action == 'show_settings':
        __addon__.openSettings()
        _zattooDB_.zapi.renew_session()
    elif action == 'watch_c':
        cid = args.get('id',['ard'])
        if cid=="current": cid=_zattooDB_.get_playing()['channel']
        start = args.get('start', '0')
        end = args.get('end', '0')
        showID = args.get('showID', '1')
        restart = args.get('restart', ['false'])
        add = args.get('add', ['false'])
        watch_channel(cid, start, end, showID, restart, add)
    elif action == 'skip_channel':
        skipDir = args.get('skipDir')
        skip_channel(int(skipDir))
    #elif action == 'toggle_channel': zattooGUI.toggle_channel()
    elif action == 'switchlist':
        if __addon__.getSetting('show_favourites')=='true':
            _listMode_ ='all'
            __addon__.setSetting('show_favourites', 'false')
        else:
            _listMode_ ='favorites'
            __addon__.setSetting('show_favourites', 'true')
        __addon__.setSetting('channellist', _listMode_)
        xbmc.executebuiltin('Container.Refresh')
    elif action == 'record_p':
        program_id = args.get('program_id')
        setup_recording(program_id)
    elif action == 'watch_r':
        recording_id = args.get('id')
        start = args.get('start', '0')
        cid = args.get('cid')
        watch_recording(recording_id, cid, start)
    elif action == 'remove_recording':
        recording_id = args.get('recording_id')
        title = args.get('title')
        delete_recording(recording_id, title)
    elif action == 'remove_series':
        recording_id = args.get('recording_id')
        series = args.get('series')
        delete_series(recording_id, series)
    elif action == 'reloadDB':
        _zattooDB_.reloadDB()
    elif action == 'changeStream':
        streams=xbmc.Player().getAvailableAudioStreams()
        dialog=xbmcgui.Dialog()
        ret = dialog.select('audio streams', streams)
        if ret==-1: return
        xbmc.Player().setAudioStream(ret)
    elif action == 'teletext':
        from .teletext import Teletext
        tele = Teletext()
        tele.doModal()
        del tele
    elif action == 'makelibrary':
        xbmc.executebuiltin("ActivateWindow(busydialog)")
        _library_.delete_library()
        _library_.make_library()
        xbmc.executebuiltin("Dialog.Close(busydialog)")
    elif action == 'resetdir':
        delete = xbmcgui.Dialog().yesno(__addonname__, __addon__.getLocalizedString(31911))
        if delete:
            _library_.delete_library()
            __addon__.setSetting(id='library_dir', value="")
            xbmc.executebuiltin('Container.Refresh')
    elif action == 'cleanProg':
        _zattooDB_.cleanProg()
    elif action == 'popular': showPreview('popular')
    elif action == 'showInfo':
        makeOsdInfo()
        osd = zattooOSD("zattooOSD.xml",__addon__.getAddonInfo('path'))
        osd.doModal()
        del osd
        
    elif action == 'nr':
        nr = args.get('nr')
        input_numbers(nr)
    
    elif action =='category':
        showCategory()
    
    elif action == 'build_category':
        cat = args.get('cat')
        build_category(cat)
    elif action == 'helpmy':
        img = args.get('img')
        _helpmy_.showHelp(img)
        
    elif action == 'showhelp': showHelp()
    
    elif action == 'inputsearch':
        search = xbmcgui.Dialog().input(__addon__.getLocalizedString(31200), type=xbmcgui.INPUT_ALPHANUM)
        if search == '': return
        search_show(search)
    
    elif action == 'deletesearch':
        dialog = xbmcgui.Dialog()
        ret = dialog.yesno(localString(320001), '[COLOR gold]'+localString(32025)+'[/COLOR]','','[COLOR red]'+local(19291)+'[/COLOR]')
        if ret == 1:
            al = args.get('al')
            search = args.get('search')
            _zattooDB_.del_search(al,search)
            xbmc.executebuiltin('Container.Refresh')
    
    elif action == 'editsearch':
        item = args.get('search')
        search = _zattooDB_.edit_search(item)
        xbmc.executebuiltin('Container.Refresh')
        
    elif action == 'vod':
        _vod_.main_menu(__addonhandle__)
    
    elif action == 'vod_sub':
        total = args.get('total')
        path = args.get('path')
        title = args.get('title')
        _vod_.sub_menu(__addonhandle__, title, path, total)
        
    elif action == 'vod_watch':
        pfad = args.get('pfad')
        params = args.get('params')
        debug(type(params))
        _vod_.vod_watch(__addonhandle__, pfad, params)
    
    elif action == 'add_wl':
        params = args.get('params')
        _vod_.add_watchlist(params)
    
    elif action == 'remove_wl':
        params = args.get('params')
        _vod_.remove_watchlist(params)
        
    elif action == 'clearCache':
        xbmcgui.Dialog().notification(localString(30104), localString(31024),  __addon__.getAddonInfo('path') + '/resources/icon.png', 3000, False)
        profilePath = xbmcvfs.translatePath(__addon__.getAddonInfo('profile'))
        os.remove(os.path.join(profilePath, 'cookie.cache'))
        os.remove(os.path.join(profilePath, 'session.cache'))
        os.remove(os.path.join(profilePath, 'account.cache'))
        _zattooDB_.zapiSession()
        
    elif action == 'showGUI':
        makeZattooGUI()
        
    elif action == 'logout':
        _zattooDB_.zapi.logout()
        
  else:
    build_root()
    
if __name__ == '__main__':   
    router(sys.argv[2][1:])    
