# # -*- coding: utf-8 -*-
#
#    copyright (C) 2023 Steffen Rolapp (github@rolapp.de)
#
#    based on ZattooBoxExtended by Daniel Griner (griner.ch@gmail.com) license under GPL
#
#    This file is part of ZattooHiQ
#
#    zattooHiQ is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    zattooHiQ is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with zattooHiQ.  If not, see <http://www.gnu.org/licenses/>.
#

import xbmc, xbmcgui, xbmcplugin, xbmcaddon, xbmcvfs
import sys, urllib.parse, os, json
import time, datetime, threading
import _strptime
import platform

from time import strftime, localtime
from urllib.parse import parse_qsl
from .myplayer import myPlayer
from .zattooDB import ZattooDB
from .library import library
from .keymap import KeyMap
from .helpmy import helpmy
from .vod import vod
from .tools import *

__addon__       = xbmcaddon.Addon()
__addonId__     = __addon__.getAddonInfo('id')
__addonname__   = __addon__.getAddonInfo('name')
__addondir__    = xbmcvfs.translatePath( __addon__.getAddonInfo('profile') )
__addonuri__    = sys.argv[0] #'plugin://plugin.video.zattoo_hiq/'
__addonhandle__ = int(sys.argv[1])

_channelList_=[]
_zattooDB_=ZattooDB()
_library_=library()
_keymap_=KeyMap()
_helpmy_=helpmy()
_vod_ = vod()
_timezone_ = int(__addon__.getSetting('time_offset'))*60*-60 #-time.altzone
_umlaut_ = {ord('ä'): 'ae', ord('ö'): 'oe', ord('ü'): 'ue', ord('ß'): 'ss'}

if __addon__.getSetting('show_favourites')=='true':_listMode_ ='favourites'
else: _listMode_ ='all'

def build_category(cat):
  #import urllib.request, urllib.parse, urllib.error

  program = _zattooDB_.get_category(cat)
  #debug('Progkategorien: '+str(program))
  if program is not None:
    channels = _zattooDB_.getChannelList(False)
    #debug('KatChannels: '+str(channels))
    content = []
    # time of chanellist creation
    content.append({'title': '[B][COLOR blue]' + cat +'[/B][/COLOR]', 'isFolder': True, 'url':__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'category'})})

    # get last watched channel
    playing = _zattooDB_.get_playing()

    nr=1
    for chan in program['index']:
      #prog=program[chan]
      # prog = {}
      # for search in channels['index']:
        # if search == chan:
          # prog = search
          # break
      #debug(str(program[chan]))
      try:
        start = program[chan]['start_date'].strftime('%H:%M')
        end = program[chan]['end_date'].strftime('%H:%M')
        startend = '[COLOR yellow]'+start+"-"+end+'[/COLOR]'
        zend = int(program[chan]['end_date'].strftime('%S'))
        zstart = int(program[chan]['start_date'].strftime('%S'))

      except AttributeError:
        startend = ''
      # get url
      streams = _zattooDB_.get_streams(chan, False)
      if streams['streams'] == 'False':
        url = "__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'watch_c', 'id': channels[chan]['id'], 'showID': prog.get('showID', '')}),"
        stream = 'False'
      else:            
        stream = streams['streams']
        url = streams['url']
      if len(str(nr)) == 1:
        chnr = '  '+str(nr)
      else: chnr = str(nr)

      if RESTART and datetime.datetime.now() < program[chan]['restart']:
        url2 = "plugin://"+__addonId__+"/?mode=watch_c&id=" + program[chan]['channel'] +'&showID=' + program[chan]['showID'] + '&restart=true'
      elif RECALL:
        url2 = "plugin://"+__addonId__+"/?mode=watch_c&id=" + program[chan]['channel'] +'&showID=' + program[chan]['showID'] + '&restart=true'
      else: url2=''
      showInfo = _zattooDB_.getShowInfo(program[chan]['showID'])
      if showInfo == 'NONE': 
        showInfo = _zattooDB_.getShowInfo(program[chan]['showID'])
      debug(showInfo)
      content.append({
        'title': '[COLOR green]'+chnr+'[/COLOR]'+'  '+channels[chan]['title'] + ' - ' + program[chan]['title']+ '  '+startend,
        'isFolder': False,
        'key': streams['key'],
        'url': url,
        #'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'watch_c', 'id': channels[chan]['id'], 'showID': program[chan]['showID']}),
        'url2': url2,
        'selected' : channels[chan]['id'] == playing['channel'],
        'duration': zend - zstart,
        'showinfo': showInfo,
        'playable': 'true',
        'header': False,
        'stream': stream,
        'showID': program[chan]['showID'],
        'logo':channels[chan]['logo'],
        'cid': chan
      })
      nr+=1

  build_directoryContent(content, False, False, 'tvshows')

def build_recordingsList():
  import urllib.request, urllib.parse, urllib.error

  resultData = _zattooDB_.zapi.exec_zapiCall('/zapi/playlist', None)
  debug('recordliste: '+str(resultData))
  if resultData is None: return

  for record in resultData['recordings']:
    showInfo=_zattooDB_.getShowInfo(record['program_id'])
    if not showInfo: continue
    if showInfo == "NONE": continue
    #mark if show is future, running or finished

    start = int(time.mktime(time.strptime(record['start'], "%Y-%m-%dT%H:%M:%SZ"))) + _timezone_  # local timestamp
    end = int(time.mktime(time.strptime(record['end'], "%Y-%m-%dT%H:%M:%SZ"))) + _timezone_  # local timestamp
    position = int(time.mktime(time.strptime(record['position'], "%Y-%m-%dT%H:%M:%SZ"))) + _timezone_  # local timestamp
    st = showInfo[0]['s']

    now = time.time()
    duration = end - start
    color='crimson'

    if (now>start): color='gold'
    if (now>end): color='lime'

    if RECREADY == "true":
        if RECNOW == "false":
          if color == "gold": continue
        if color == "crimson": continue

    if __addon__.getSetting('rec_name') == '0':
        label=datetime.datetime.fromtimestamp(st).strftime('%Y.%m.%d. %H:%M')+' '
    elif __addon__.getSetting('rec_name') == '1':
        label=datetime.datetime.fromtimestamp(st).strftime('%a %d.%m.%Y. %H:%M')+' '
    if record['episode_title']:
      label+='[COLOR '+color+']'+record['title']+'[/COLOR]: '+record['episode_title']
      title=record['title']+': '+record['episode_title']
     # meta = {'title':record['episode_title'], 'tvshowtitle':record['title']}
    else:
      label+='[COLOR '+color+']'+record['title']+'[/COLOR]'
      title=record['title']
     # meta = {'title':record['title']}
    if showInfo == "NONE": continue
    label+=' ('+showInfo[0]['channel_name']+')'

    director = []
    cast = []

    if showInfo[0]['cr'] != []:
        director = showInfo[0]['cr']['director']
        od=1
    for actor in showInfo[0]['cast']:
        if actor['i_t'] is not None:
            thumbnail = str('images.zattic.com/cms/' + actor['i_t'] +'/format_480x360.jpg')
        cast.append(xbmc.Actor(actor['f_n'],actor['c_n'],od,thumbnail))
        od = od+1

    country = [showInfo[0]['country']]

    date = datetime.datetime.fromtimestamp(start).strftime('%d.%m.%Y')
    li = xbmcgui.ListItem(label)
    vinfo = li.getVideoInfoTag()
    vinfo.setResumePoint(position-start+300, end-start)
    vinfo.setTitle(label)
    vinfo.setYear(showInfo[0]['year'])
    vinfo.setPlot(showInfo[0]['d'])
    vinfo.setCountries(country)
    vinfo.setDirectors(director)
    vinfo.setCast(cast)
    vinfo.setGenres(showInfo[0]['g'])
    vinfo.setDuration(showInfo[0]['e'] - showInfo[0]['s'])
    vinfo.setSortTitle(record['title'])

    '''
    #mark watched
    if (position>end-660):  #10min padding from zattoo +1min safety margin
        meta.update({'overlay':7, 'playcount':12})
    '''

    if record['image_token'] is not None:
      image_url = 'https://images.zattic.com/cms/' + record['image_token'] + '/format_480x360.jpg'
      li.setArt({'thumb':image_url, 'fanart':image_url, 'landscape':image_url})
    li.setProperty('IsPlayable', 'true')
    li.setProperty('zStartTime', str(start))

    try:
      series=record['tv_series_id']
    except:
      seriesrec = 'None'

    try:
      if resultData['recorded_tv_series']:
        for ser in resultData['recorded_tv_series']:
          if series == ser['tv_series_id']:
            seriesrec = 'true'
            #debug('SeriesID '+str(series))
            break
          else:
            seriesrec = 'None'
    except:
      seriesrec = 'None'

    contextMenuItems = []
    contextMenuItems.append(('Info', 'Action(Info)'))
    contextMenuItems.append((localString(31926), 'Action(ToggleWatched)'))
    if seriesrec == 'true':
      contextMenuItems.append((localString(31925),'RunPlugin("plugin://'+__addonId__+'/?mode=remove_series&recording_id='+str(record['id'])+'&series='+str(series)+'")',))
    contextMenuItems.append((localString(31921), 'RunPlugin("plugin://'+__addonId__+'/?mode=remove_recording&recording_id='+str(record['id'])+'&title='+str(title)+'")'))
    li.addContextMenuItems(contextMenuItems, replaceItems=True)

    xbmcplugin.addDirectoryItem(
      handle=__addonhandle__,
      url=__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'watch_r', 'id': record['id'], 'cid': record['cid'], 'start': start}),
      listitem=li,
      isFolder=False
    )
  
  xbmcplugin.setContent(__addonhandle__, 'movies')
  xbmcplugin.addSortMethod(__addonhandle__, xbmcplugin.SORT_METHOD_LABEL)
  xbmcplugin.addSortMethod(__addonhandle__, xbmcplugin.SORT_METHOD_DATE)
  xbmcplugin.addSortMethod(__addonhandle__, xbmcplugin.SORT_METHOD_VIDEO_SORT_TITLE)
  xbmcplugin.addSortMethod(__addonhandle__, xbmcplugin.SORT_METHOD_GENRE)
  xbmcplugin.endOfDirectory(__addonhandle__, succeeded=True, cacheToDisc=False)
  
def build_channelsList():
  global __addonuri__, _listMode_ 
  __addonuri__ = 'plugin://plugin.video.zattoo_hiq/'

  #import urllib.request, urllib.parse, urllib.error
  channels = _zattooDB_.getChannelList(_listMode_ == 'favourites')
  li = False
  nr=0
  for chan in channels['index']:
    nr+=1
  if channels is not None:
    # get currently playing shows
    if __addon__.getSetting('dbonstart') == 'true': li = True
    program = _zattooDB_.getPrograms(channels)
    content = []
    # time of chanellist creation
    if _listMode_ == 'favourites':
      content.append({'title': '[B][COLOR blue]' + 'Favourites ('+str(nr)+')' +'[/B][/COLOR]', 'isFolder': True, 'url': __addonuri__ + '?' + urllib.parse.urlencode({'mode': 'switchlist'})})
    else:
      content.append({'title': '[B][COLOR blue]' + 'All ('+str(nr)+')' +'[/B][/COLOR]', 'isFolder': True, 'url':__addonuri__ + '?' + urllib.parse.urlencode({'mode': 'switchlist'})})
     
    # get last watched channel
    playing = _zattooDB_.get_playing()

    nr=1
    for chan in channels['index']:
        #prog=program[chan]
        prog = {}
        for search in program:
            if search['channel'] == chan:
              prog = search
              break
        try:
            start = prog.get('start_date','').strftime('%H:%M')
            end = prog.get('end_date','').strftime('%H:%M')
            startend = '[COLOR yellow]'+start+"-"+end+'[/COLOR]'
            zstart = int(time.mktime(prog.get('start_date', '').timetuple()))
            zend = int(time.mktime(prog.get('end_date', '').timetuple()))
        except AttributeError:
            startend = ''
        if len(str(nr)) == 1:
            chnr = '  '+str(nr)
        else: chnr = str(nr)
        # get url
        streams = _zattooDB_.get_streams(chan, False)
        if streams['streams'] == 'False':
            url = "__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'watch_c', 'id': channels[chan]['id'], 'showID': prog.get('showID', '')}),"
            stream = 'False'
        else:            
            stream = streams['streams']
            url = streams['url']
        if type(prog.get('restart','')) == str: continue
        #debug(RECALL)
        if RESTART and datetime.datetime.now() < prog.get('restart',''):
            url2 = "plugin://"+__addonId__+"/?mode=watch_c&id=" + prog.get('channel', '') +'&showID=' + prog.get('showID','') + '&restart=true'
        elif RECALL:
            url2 = "plugin://"+__addonId__+"/?mode=watch_c&id=" + prog.get('channel', '') +'&showID=' + prog.get('showID','') + '&restart=true'
        else: url2=''
        showInfo = _zattooDB_.getShowInfo(prog.get('showID'))
        if showInfo == 'NONE': 
            showInfo = _zattooDB_.getShowInfo(prog.get('showID'))
        if showInfo == 'NONE': showInfo = []
            
        content.append({
            'title': '[COLOR lime]'+chnr+'[/COLOR]'+'  '+channels[chan]['title'] + ' - ' + prog.get('title', '')+ '  '+startend,
            'isFolder': False,            
            'url': url,
            'key': streams['key'],
            'url2': url2,
            'selected' : channels[chan]['id'] == playing['channel'],
            'duration': zend - zstart,
            'start': zstart,
            'end': zend,
            'showinfo': showInfo,
            'playable': 'true',
            'header': False,
            'stream': stream,
            'cid': chan,
            'showID': prog['showID'],
            'logo':channels[chan]['logo']
                            
        })
        nr+=1
        
  build_directoryContent(content, False, False, 'tvshows')

def build_directoryContent(content, cache=True, root=False, con='movies'):
  global __addonhandle__, player
  xbmcgui.Window(10000).setProperty('zattooGUI', 'False')
  #debug('Liste: '+str(content))
  for record in content:
    rec = dict(record)
    #record['thumbnail'] = record.get('thumbnail', FANART_IMG)
    record['selected'] = record.get('selected', False)
    record['url2'] = record.get('url2', '')
    record['isFolder'] = rec['isFolder']
    playable = record.get('playable','false')
    header = record.get('header', True)
    image = record.get('image', FANART_IMG)
    logo = record.get('logo',FANART_IMG)
    stream = record.get('stream', False)
    li = xbmcgui.ListItem(record['title'])
    #debug(stream)
    if con == 'tvshows':
        if header == False:
            if rec['showinfo'] != []: 
                showinfo = rec['showinfo']
                vinfo = li.getVideoInfoTag()
                if showinfo[0]['year']:
                    vinfo.setYear(showinfo[0]['year'])
                vinfo.setPlot(showinfo[0]['d'])
                vinfo.setCountries([showinfo[0]['country']])
                cast = []
                director = []
                if showinfo[0]['cr'] != []:
                    director = showinfo[0]['cr']['director']
                od=1
                for actor in showinfo[0]['cast']:
                    thumbnail = ''
                    if actor['i_t'] is not None:
                        thumbnail = str('images.zattic.com/cms/' + actor['i_t'] +'/format_480x360.jpg')
                    cast.append(xbmc.Actor(actor['f_n'],actor['c_n'],od,thumbnail))
                    od = od+1
                vinfo.setCast(cast)
                vinfo.setGenres(showinfo[0]['g'])
                vinfo.setDuration(rec['duration'])
                #vinfo.setResumePoint(rec['start'])
                vinfo.setDirectors(director)
                if showinfo[0]['s_no'] is not None:
                    vinfo.setSeason(showinfo[0]['s_no'])
                if showinfo[0]['e_no'] is not None:
                    vinfo.setEpisode(showinfo[0]['e_no'])
                vinfo.setUniqueIDs({'tvdb':rec['cid'], 'imdb':rec['showID']})
                #vinfo.setResumePoint(0, rec['duration'])
                #li.setProperty('StartTime',str(rec['start']))
                #li.setProperty('EndTime',str(rec['end']))
                image = showinfo[0]['i_url']
            if record['stream'] != 'False':
            
                if record['key']:
                    li.setProperty('inputstream', 'inputstream.adaptive')
                    li.setProperty('inputstream.adaptive.manifest_type', 'mpd')
                    li.setProperty('inputstream.adaptive.license_key', record['key'] + "||a{SSM}|")
                    li.setProperty('inputstream.adaptive.license_type', "com.widevine.alpha")
                else:
                    li.setProperty('inputstream', 'inputstream.adaptive')
                    li.setProperty('inputstream.adaptive.manifest_type', 'mpd')

    li.setArt({'icon': logo, 'thumb': logo, 'poster': image, 'banner': image})
    li.setProperty('Fanart_Image', image)
    li.setProperty('IsPlayable', playable)
    li.select(record['selected'])

    # context menu
    contextMenuItems = []
    contextMenuItems.append(('Info', 'Action(Info)'))
    if record['url2'] !='':
       contextMenuItems.append((localString(31301), 'RunPlugin('+str(record['url2'])+')') )
    if localString(31107) in record['title']:
       contextMenuItems.append((localString(31023), 'RunPlugin(plugin://plugin.video.zattoo_hiq/?mode=reloadDB)'))
    li.addContextMenuItems(contextMenuItems, replaceItems=True)
    #debug(rec['url'])
    xbmcplugin.addDirectoryItem(
        handle=__addonhandle__,
        url=record['url'], 
        listitem=li, 
        isFolder=record['isFolder']
        )
    
  xbmcplugin.setContent(__addonhandle__, con)
  xbmcplugin.setPluginFanart(__addonhandle__, FANART_IMG)
  xbmcplugin.endOfDirectory(__addonhandle__, succeeded=True, updateListing=root, cacheToDisc=False)

  #if con == 'tvshows':
  #      th = threading.Thread(target=container_refresh)
  #      th.start()
  #      makeZattooGUI()
  
def build_root():
  import urllib.request, urllib.parse, urllib.error

  # check if settings are set
  name = __addon__.getSetting('username')
  if name == '':
    # show home window, zattooHiQ settings and quit
    xbmc.executebuiltin('ActivateWindow(10000)')
    xbmcgui.Dialog().ok(__addonname__, localString(31902))
    __addon__.openSettings()
    sys.exit()

  #play channel on open addon
  if ((xbmcgui.Window(10000).getProperty('ZBEplayOnStart')!='false') and (not xbmc.Player().isPlaying()) and (__addon__.getSetting('start_liveTV')=='true')):
    channeltitle = __addon__.getSetting('start_channel')
    if channeltitle=="lastChannel":
        channelid=_zattooDB_.get_playing()['channel']
    elif channeltitle == "":
        channelid = _zattooDB_.get_firstchan()
    else:
        channelid = _zattooDB_.get_channelid(channeltitle)
    prog = _zattooDB_.getPrograms({'index': [channelid]})
    showID = prog[0]['showID']
    url = "plugin://"+__addonId__+"/?mode=watch_c&id=" + channelid + '&showID=' + showID
    debug(url)
    xbmc.executebuiltin('RunPlugin('+url+')')
    xbmcgui.Window(10000).setProperty('ZBEplayOnStart', 'false')

#  if _listMode_ == 'all': listTitle = localString(31100)
  iconPath = __addon__.getAddonInfo('path') + '/resources/icon.png'
  if _listMode_ == 'all': listTitle = localString(31100)
  else: listTitle = localString(31101)
#  if _listMode_ == 'all': listTitle = localString(31100)
  RecLimit = __addon__.getSetting('record')
  content = [

    {'title': '[COLOR ff00ff00]'+localString(31099)+'[/COLOR]', 'image': POPULAR_IMG, 'thumbnail': POPULAR_IMG, 'isFolder': False, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'popular'})},
    {'title': localString(31103), 'image': PREVIEW_IMG, 'thumbnail': PREVIEW_IMG, 'isFolder': False, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'preview'})},
    {'title': localString(31104), 'image': EPG_IMG, 'thumbnail': EPG_IMG, 'isFolder': False, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'epg'})},
    {'title': localString(31102), 'image': LIST_IMG, 'thumbnail': LIST_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'channellist'})},
    {'title': localString(31105), 'image': SEARCH_IMG, 'thumbnail': SEARCH_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'searchlist', })},
  ]
  if VOD:
    content.append({'title': localString(31109), 'image': VOD_IMG, 'thumbnail': VOD_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'vod',})},)
  if RECORD:
    content.append({'title': localString(31106) + ' ' + RecLimit, 'image': RECORD_IMG, 'thumbnail': RECORD_IMG,'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'recordings'})},)
  content.append({'title': localString(31108), 'image': KAT_IMG, 'thumbnail': KAT_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'category'})},)

  if __addon__.getSetting('help') == "true":
    content.append({'title': '[COLOR yellow]'+local(10043)+'[/COLOR]', 'image': HELP_IMG, 'thumbnail': HELP_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'showhelp'})})
  if __addon__.getSetting('settings') == "true":
    content.append({'title': '[COLOR yellow]'+localString(31107)+' '+__addonname__+' - v.'+VERSION+'[/COLOR]', 'image': SETTING_IMG, 'thumbnail': SETTING_IMG, 'isFolder': False, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'show_settings'})})

  build_directoryContent(content, True, False, 'files')


def build_searchList():
  import urllib.request, urllib.parse, urllib.error
  #__addonuri__= sys.argv[0]
  #__addonhandle__ = int(sys.argv[1])
  search = _zattooDB_.get_search()
  debug('Search '+str(search))


  if search is not None:
        xbmcplugin.addDirectoryItem(
          handle=__addonhandle__,
          url=__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'inputsearch'}),
          listitem=xbmcgui.ListItem('[B][COLOR blue]' + localString(320000) +'[/B][/COLOR]'),
          isFolder=True
        )
        xbmcplugin.addDirectoryItem(
          handle=__addonhandle__,
          url=__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'deletesearch', 'al': True, 'search': '_'}),
          listitem=xbmcgui.ListItem('[B][COLOR blue]' + localString(320001) +'[/B][/COLOR]'),
          isFolder=True
        )
        for chan in search['index']:
            debug(chan)
            #li = xbmcgui.ListItem(search[chan]['id'])
            li = xbmcgui.ListItem(chan)
            contextMenuItems = []
            contextMenuItems.append((localString(320002), 'RunPlugin("plugin://'+__addonId__+'/?mode=deletesearch&al=False&search='+str(chan)+'")'))
            contextMenuItems.append((localString(320003), 'RunPlugin("plugin://'+__addonId__+'/?mode=editsearch&search='+str(chan)+'")'))
            li.addContextMenuItems(contextMenuItems, replaceItems=True)
            xbmcplugin.addDirectoryItem(
              handle=__addonhandle__,
              url=__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'search', 'id': str(chan)}),
              listitem=li,
              isFolder=True
            )


  xbmcplugin.setContent(__addonhandle__, 'movies')
  xbmcplugin.addSortMethod(__addonhandle__, xbmcplugin.SORT_METHOD_LABEL)
  xbmcplugin.endOfDirectory(__addonhandle__, succeeded=True, updateListing=True, cacheToDisc=False)


def build_channelsList():
  global __addonuri__, _listMode_ 
  __addonuri__ = 'plugin://plugin.video.zattoo_hiq/'

  #import urllib.request, urllib.parse, urllib.error
  channels = _zattooDB_.getChannelList(_listMode_ == 'favourites')
  li = False
  nr=0
  for chan in channels['index']:
    nr+=1
  if channels is not None:
    # get currently playing shows
    if __addon__.getSetting('dbonstart') == 'true': li = True
    program = _zattooDB_.getPrograms(channels)
    content = []
    # time of chanellist creation
    if _listMode_ == 'favourites':
      content.append({'title': '[B][COLOR blue]' + 'Favourites ('+str(nr)+')' +'[/B][/COLOR]', 'isFolder': True, 'url': __addonuri__ + '?' + urllib.parse.urlencode({'mode': 'switchlist'})})
    else:
      content.append({'title': '[B][COLOR blue]' + 'All ('+str(nr)+')' +'[/B][/COLOR]', 'isFolder': True, 'url':__addonuri__ + '?' + urllib.parse.urlencode({'mode': 'switchlist'})})
     
    # get last watched channel
    playing = _zattooDB_.get_playing()

    nr=1
    for chan in channels['index']:
        #prog=program[chan]
        prog = {}
        for search in program:
            if search['channel'] == chan:
              prog = search
              break
        try:
            start = prog.get('start_date','').strftime('%H:%M')
            end = prog.get('end_date','').strftime('%H:%M')
            startend = '[COLOR yellow]'+start+"-"+end+'[/COLOR]'
            zstart = int(time.mktime(prog.get('start_date', '').timetuple()))
            zend = int(time.mktime(prog.get('end_date', '').timetuple()))
        except AttributeError:
            startend = ''
        if len(str(nr)) == 1:
            chnr = '  '+str(nr)
        else: chnr = str(nr)
        # get url
        streams = _zattooDB_.get_streams(chan, False)
        if streams['streams'] == 'False':
            url = "__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'watch_c', 'id': channels[chan]['id'], 'showID': prog.get('showID', '')}),"
            stream = 'False'
        else:            
            stream = streams['streams']
            url = streams['url']
        if type(prog.get('restart','')) == str: continue
        #debug(RECALL)
        if RESTART and datetime.datetime.now() < prog.get('restart',''):
            url2 = "plugin://"+__addonId__+"/?mode=watch_c&id=" + prog.get('channel', '') +'&showID=' + prog.get('showID','') + '&restart=true'
        elif RECALL:
            url2 = "plugin://"+__addonId__+"/?mode=watch_c&id=" + prog.get('channel', '') +'&showID=' + prog.get('showID','') + '&restart=true'
        else: url2=''
        showInfo = _zattooDB_.getShowInfo(prog.get('showID'))
        if showInfo == 'NONE': 
            showInfo = _zattooDB_.getShowInfo(prog.get('showID'))
        if showInfo == 'NONE': showInfo = []
            
        content.append({
            'title': '[COLOR lime]'+chnr+'[/COLOR]'+'  '+channels[chan]['title'] + ' - ' + prog.get('title', '')+ '  '+startend,
            'isFolder': False,            
            'url': url,
            'key': streams['key'],
            'url2': url2,
            'selected' : channels[chan]['id'] == playing['channel'],
            'duration': zend - zstart,
            'start': zstart,
            'end': zend,
            'showinfo': showInfo,
            'playable': 'true',
            'header': False,
            'stream': stream,
            'cid': chan,
            'showID': prog['showID'],
            'logo':channels[chan]['logo']
                            
        })
        nr+=1
        
  build_directoryContent(content, False, False, 'tvshows')

def showCategory():
    
    cat = _zattooDB_.set_category()
    #debug('Kategorien: '+str(cat))

    content = []

    for record in cat:
      content.append(
      {
        'title':record['category']+' ('+str(record['len'])+')',
        'image': ICON_IMG,
        'isFolder': True,
        'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'build_category', 'cat': record['category']})
      })

    build_directoryContent(content, False )
