# # -*- coding: utf-8 -*-
#
#    copyright (C) 2023 Steffen Rolapp (github@rolapp.de)
#
#    based on ZattooBoxExtended by Daniel Griner (griner.ch@gmail.com) license under GPL
#
#    This file is part of ZattooHiQ
#
#    zattooHiQ is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    zattooHiQ is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with zattooHiQ.  If not, see <http://www.gnu.org/licenses/>.
#

import xbmc, xbmcgui, xbmcplugin, xbmcaddon, xbmcvfs
import sys, urllib.parse, os, json
import time, datetime, threading
import _strptime
import platform

from time import strftime, localtime
from urllib.parse import parse_qsl
#from .myplayer import myPlayer
from .zattooDB import ZattooDB
from .library import library
from .guiactions import *
from .keymap import KeyMap
from .helpmy import helpmy
from .vod import vod
#from .gui import zattooGUI
#from .gui import zattooOSD
#from .gui import *


__addon__       = xbmcaddon.Addon()
__addonId__     = __addon__.getAddonInfo('id')
__addonname__   = __addon__.getAddonInfo('name')
__addondir__    = xbmcvfs.translatePath( __addon__.getAddonInfo('profile') )
__addonuri__    = sys.argv[0] #'plugin://plugin.video.zattoo_hiq/'

_timezone_ = int(__addon__.getSetting('time_offset'))*60*-60 #-time.altzone
_umlaut_ = {ord('ä'): 'ae', ord('ö'): 'oe', ord('ü'): 'ue', ord('ß'): 'ss'}
localString = __addon__.getLocalizedString
local = xbmc.getLocalizedString
DEBUG = __addon__.getSetting('debug')
#player = myPlayer()

if __addon__.getSetting('show_favourites')=='true':_listMode_ ='favourites'
else: _listMode_ ='all'

_channelList_=[]
_zattooDB_=ZattooDB()
_library_=library()
_keymap_=KeyMap()
_helpmy_=helpmy()
_vod_ = vod()

#_keymap_.saveKeyMap()
_keymap_.toggleKeyMap()

### Account Data ###

#accountData=_zattooDB_.zapi.get_accountData()
#hiq = accountData['account']['permissions']
accountData = _zattooDB_.zapi.exec_zapiCall('/zapi/v2/session', None)
hiq = accountData['session']['user']['products']

if hiq == []:
    premiumUser = False
    __addon__.setSetting('accounttype', 'Free')
else:
    premiumUser = True
    __addon__.setSetting('accounttype', str(hiq[0]['name']))

accountData=_zattooDB_.zapi.get_accountData()
# Set Recall
try:
    if "recall_activated" in accountData['account']['permissions']  and accountData['nonlive']['replay_availability'] == 'available':
            RECALL = True
    else:
            RECALL = False
except:
    RECALL = False

# Set Restart
try:
    if "recall_eligible" in accountData['account']['permissions'] and accountData['nonlive']['replay_availability'] == 'available':
        RESTART = True
    else:
        RESTART = False
except:
    RESTART = False

# Set Vod
try:
    if accountData['nonlive']["vod_eligible"]:
        VOD = accountData['nonlive']["vod_eligible"]
    else:
        VOD = False
except:
    VOD = False

# Set Settings Info
if accountData['nonlive']['replay_availability'] == 'available':
    __addon__.setSetting('recall', localString(310032))
    __addon__.setSetting('recall_bool', 'true')
elif accountData['nonlive']['replay_availability'] == 'needs_activation':
    __addon__.setSetting('recall', localString(310036))
    __addon__.setSetting('recall_bool', 'false')
else:
    __addon__.setSetting('recall', localString(310039))
    __addon__.setSetting('recall_bool', 'false')

# Set Youth Protection PIN
try:
    params = {'password': __addon__.getSetting('password')}
    req = _zattooDB_.zapi.exec_zapiCall('/zapi/account/get_pin', params)
    YPIN = req['pin']
    __addon__.setSetting('ypin', YPIN)
except:
    YPIN = __addon__.getSetting('ypin')

if len(YPIN) != 4:
    xbmcgui.Dialog().ok(__addonname__, localString(31927))
    __addon__.openSettings()

# pin = _zattooDB_.zapi.exec_zapiCall('/zapi/account/pin_toggle', None)


try:
  SERIE=accountData['nonlive']['series_recording_eligible']
except KeyError:SERIE = False

try:
    if accountData['nonlive']['recording_number_limit'] > 0:
        RECORD = True
        resultData = _zattooDB_.zapi.exec_zapiCall('/zapi/playlist', None)
        RecCount = len(resultData['recordings'])
        __addon__.setSetting('record', str(RecCount) + '/' + str(accountData['nonlive']['recording_number_limit']))
except KeyError:
    RECORD = False
    __addon__.setSetting('record', localString(310039))

try:
  country=accountData['account']['service_country']
  __addon__.setSetting('country', country)
except: pass


if __addon__.getSetting('country') == 'CH': SWISS = True
else: SWISS = False

## Images ##
ICON_IMG = __addon__.getAddonInfo('path') + '/resources/icon.png'
FANART_IMG = __addon__.getAddonInfo('path') + 'resources/fanart.jpg'
LIST_IMG = __addon__.getAddonInfo('path') + '/resources/media/list.png'
HELP_IMG = __addon__.getAddonInfo('path') + '/resources/media/help.png'
SETTING_IMG = __addon__.getAddonInfo('path') + '/resources/media/setting.png'
RECORD_IMG = __addon__.getAddonInfo('path') + '/resources/media/record.png'
POPULAR_IMG = __addon__.getAddonInfo('path') + '/resources/media/popular.png'
SEARCH_IMG = __addon__.getAddonInfo('path') + '/resources/media/search.png'
VOD_IMG = __addon__.getAddonInfo('path') + '/resources/media/vod.png'
PREVIEW_IMG = __addon__.getAddonInfo('path') + '/resources/media/preview.png'
EPG_IMG = __addon__.getAddonInfo('path') + '/resources/media/epg.png'
KAT_IMG = __addon__.getAddonInfo('path') + '/resources/media/kat.png'

#stream_type = __addon__.getSetting('stream_type')
RECREADY = __addon__.getSetting('rec_ready')
RECNOW = __addon__.getSetting('rec_now')
VERSION = __addon__.getAddonInfo('version')
DOLBY = __addon__.getSetting('dolby')
KEYMAP = __addon__.getSetting('keymap')
PLAYLIST = xbmc.PlayList(xbmc.PLAYLIST_VIDEO)

if premiumUser or SWISS:
  xbmc.executebuiltin( "Skin.SetBool(%s)" %'record')
else:
  xbmc.executebuiltin( "Skin.Reset(%s)" %'record')

if RECALL:
  xbmc.executebuiltin( "Skin.SetBool(%s)" %'restart')
else:
  xbmc.executebuiltin( "Skin.Reset(%s)" %'restart')
    
def debug(content):
    if DEBUG:log(content, xbmc.LOGDEBUG)

def notice(content):
    log(content, xbmc.LOGINFO)

def log(msg, level=xbmc.LOGINFO):
    addon = xbmcaddon.Addon()
    addonID = addon.getAddonInfo('id')
    xbmc.log('%s: %s' % (addonID, msg), level)

def convert_date(date):
    debug(date)
    try:
        res = datetime.datetime.strptime(date, "%Y-%m-%dT%H:%M:%SZ")
    except TypeError:
        res = datetime.datetime(*(time.strptime(date, "%Y-%m-%dT%H:%M:%SZ")[0:6]))
    res += datetime.timedelta(seconds=_timezone_)
    return str(res.strftime('%A,%d.%B %Y %H:%M'))
    
def convert_date(date):
    debug(date)
    try:
        res = datetime.datetime.strptime(date, "%Y-%m-%dT%H:%M:%SZ")
    except TypeError:
        res = datetime.datetime(*(time.strptime(date, "%Y-%m-%dT%H:%M:%SZ")[0:6]))
    res += datetime.timedelta(seconds=_timezone_)
    return str(res.strftime('%A,%d.%B %Y %H:%M'))

def formatTime(timestamp):
    if timestamp:
        format = xbmc.getRegion('time').replace(':%S', '').replace('%H%H', '%H')
        return timestamp.strftime(format)
    else:
        return ''
  
def formatDate(timestamp, format):
    if timestamp:
        date = timestamp.strftime(format)
        date = date.replace('Monday', local(11))
        date = date.replace('Tuesday', local(12))
        date = date.replace('Wednesday', local(13))
        date = date.replace('Thursday', local(14))
        date = date.replace('Friday', local(15))
        date = date.replace('Saturday', local(16))
        date = date.replace('Sunday', local(17))
        date = date.replace('January', local(21))
        date = date.replace('February', local(22))
        date = date.replace('March', local(23))
        date = date.replace('April', local(24))
        date = date.replace('May', local(25))
        date = date.replace('June', local(26))
        date = date.replace('July', local(27))
        date = date.replace('August', local(28))
        date = date.replace('September', local(29))
        date = date.replace('October', local(30))
        date = date.replace('November', local(31))
        date = date.replace('December', local(32))
        return date
    else:
        return ''

def to_seconds(date):
    return time.mktime(date.timetuple())

def showEpg():
    from .epg import EPG
    currentChannel = _zattooDB_.get_playing()['channel']
    channelList = _zattooDB_.getChannelList(_listMode_ == 'favourites')
    #debug(str(channelList))
    try:
        currentNr=channelList[currentChannel]['nr']
    except:
        currentNr=0
  
    epg = EPG(currentNr)
    epg.loadChannels(_listMode_ == 'favourites')
    #epg.show() 
    epg.doModal()
    #while xbmcgui.Window(10000).getProperty('zattoo_runningView')=="epg": xbmc.sleep(200)
    del epg

def watch_channel(channel_id, start, end, showID="", recall='false', add='false'):
    global player
    #player = xbmc.Player()
    #_keymap_.toggleKeyMap()
    _zattooDB_=ZattooDB()
    
    #selected currently playing live TV
    playing = _zattooDB_.get_playing()
    xbmcgui.Window(10000).setProperty('lastChannel', playing['channel'])

    pre = __addon__.getSetting('pre_padding')
    post = __addon__.getSetting('post_padding')
    drm = _zattooDB_.get_drm(channel_id)
  
    if recall == 'true':
        debug(recall)
        params = {'enable_eac3':DOLBY, 'pre_padding':pre, 'post_padding':post, 'youth_protection_pin': YPIN}
        if drm: 
            params['stream_type'] = 'dash_widevine'
            params['max_drm_lvl'] = '3'
            if SWISS:
                debug('swiss')
                if platform.system() == 'Linux':
                    #params['quality'] = 'sd'
                    params['stream_type'] = 'dash'
        else:
            params['stream_type'] = 'dash'
        resultData = _zattooDB_.zapi.exec_zapiCall('/zapi/v3/watch/replay/' + channel_id + '/' + showID, params)

        if resultData is None:
            #if add == 'true': return
            xbmcgui.Dialog().notification("ERROR", "NO ZAPI RESULT", channelInfo['logo'], 5000, False)
            return  
        streams = resultData['stream']['watch_urls']
        if len(streams)==0:
            xbmcgui.Dialog().notification("ERROR", "NO STREAM FOUND, CHECK SETTINGS!", channelInfo['logo'], 5000, False)
            return
        # change stream if settings are set
        elif len(streams) > 1 and  __addon__.getSetting('audio_stream') == 'B' and streams[1]['audio_channel'] == 'B': streamNr = 1
        else:  streamNr = 0
        url = streams[streamNr]['url']
    else:
        data = _zattooDB_.get_streams(channel_id) 
        streams = data['streams']
        url = data['url']
        key =data['key']
    # save currently playing
    if showID == '1':
        prog = _zattooDB_.getPrograms({'index':[channel_id]})
        showID = prog[0]['showID']
    program = _zattooDB_.get_showID(showID)
    showinfo = _zattooDB_.getShowInfo(showID)
    channelInfo = _zattooDB_.get_channelInfo(channel_id)
        
    listitem = xbmcgui.ListItem(path=url)      
    if program:
        program = program[0]
        heading = ('[B]' + channelInfo['title'] + '[/B] ').translate(_umlaut_) + '  ' + program['start_date'].strftime('%H:%M') + '-' + program['end_date'].strftime('%H:%M')
        xbmcgui.Dialog().notification(heading, program['title'].translate(_umlaut_), channelInfo['logo'], 5000, False)
    
        #set info for recall
        vinfo = listitem.getVideoInfoTag()
        vinfo.setTvShowTitle(channelInfo['title'])# + ', ' + formatDate(program['start_date'],strftime('%A %H:%M') + '-' + program['end_date'],strftime('%H:%M')))
        vinfo.setTitle(program['title'])
        #vinfo.setResumePoint(0, program['duration'])
        vinfo.setPath(url)
        vinfo.setUniqueIDs({'tvdb':channel_id, 'imdb':showID})
        #meta = { 'title': prog['title'], 'episode': streamNr, 'tvshowtitle': channelInfo['title']+ ', ' + formatDate(prog['start_date'],'%A %H:%M') + '-' + prog['end_date'].strftime('%H:%M'), 'premiered' :'premiered', 'duration' : '20', 'rating': 'rating', 'director': 'director', 'writer': 'writer', 'plot': program['description_long']}
        #listitem.setInfo("Video", meta)
        listitem.setLabel(program['title'] + ' - ' + str(program['description']))
        listitem.setArt({ 'icon': channelInfo['logo'], 'poster': channelInfo['logo'], 'clearlogo' : channelInfo['logo'], 'thumb': channelInfo['logo']})
        listitem.setInfo('Video',{'director': channel_id, 'writer': showID})
    
    if drm:
        listitem.setProperty('inputstream', 'inputstream.adaptive')
        listitem.setProperty('inputstream.adaptive.manifest_type', 'mpd')
        listitem.setProperty('inputstream.adaptive.license_key', key + "||a{SSM}|")
        listitem.setProperty('inputstream.adaptive.license_type', "com.widevine.alpha")
    
    else:
        listitem.setProperty('inputstream', 'inputstream.adaptive')
        listitem.setProperty('inputstream.adaptive.manifest_type', 'mpd')
        
    listitem.setProperty('isplayable', 'true')
    listitem.setIsFolder(False)
      
    #xbmcplugin.setResolvedUrl(__addonhandle__, True, listitem)
  
    #play liveTV: info is created in OSD
    # set add to playlist
    afterRecall = __addon__.getSetting('after_recall')
    xbmcgui.Window(12005).setProperty('after_recall', afterRecall)
  
    #play liveTV: info is created in OSD
    # GreenAir: play live stream or recall without PLAYLIST

    if recall=='false' or afterRecall != '3':
      player.PlayStream(url, listitem)
      #th = threading.Thread(target=container_refresh)
      #th.start()
      #makeZattooGUI()
      

    else:
        PLAYLIST.add(url=streams[streamNr]['url'], listitem=listitem)
        # GreenAir: start playing PLAYLIST if this is the first entry
        if PLAYLIST.size()==1:
            player.PlayStream(PLAYLIST)
            #GreenAir: don't block execution, showToggleImg() has to create zattooPiP on return
            #while player.isPlaying():xbmc.sleep(100)

def container_refresh():
    monitor = xbmc.Monitor()
    while not monitor.abortRequested():
        if monitor.waitForAbort(300): break
        xbmc.executebuiltin('Container.Refresh')    
        
# def makeZattooGUI():
    # while xbmcgui.Window(10000).getProperty('zattooGUI') == 'False':
        # xbmc.sleep(200)

    # xbmcgui.Dialog().notification('ZattooHiQ', 'GUI started', xbmcgui.NOTIFICATION_INFO, 1500, False)
    # gui = zattooGUI("zattooGUI.xml", __addon__.getAddonInfo('path'))
    # gui.doModal()
    # del gui
    # xbmcgui.Window(10000).setProperty('zattooGUI', 'False')
    # xbmcgui.Dialog().notification('ZattooHiQ', 'GUI beendet', xbmcgui.NOTIFICATION_WARNING, 2000, False)

# def build_directoryContent(content, cache=True, root=False, con='movies'):
  # global __addonhandle__, player
  # xbmcgui.Window(10000).setProperty('zattooGUI', 'False')
  # #debug('Liste: '+str(content))
  # for record in content:
    # rec = dict(record)
    # #record['thumbnail'] = record.get('thumbnail', FANART_IMG)
    # record['selected'] = record.get('selected', False)
    # record['url2'] = record.get('url2', '')
    # record['isFolder'] = rec['isFolder']
    # playable = record.get('playable','false')
    # header = record.get('header', True)
    # image = record.get('image', FANART_IMG)
    # logo = record.get('logo',FANART_IMG)
    # stream = record.get('stream', False)
    # li = xbmcgui.ListItem(record['title'])
    # #debug(stream)
    # if con == 'tvshows':
        # if header == False:
            # if rec['showinfo'] != []: 
                # showinfo = rec['showinfo']
                # vinfo = li.getVideoInfoTag()
                # if showinfo[0]['year']:
                    # vinfo.setYear(showinfo[0]['year'])
                # vinfo.setPlot(showinfo[0]['d'])
                # vinfo.setCountries([showinfo[0]['country']])
                # cast = []
                # director = []
                # if showinfo[0]['cr'] != []:
                    # director = showinfo[0]['cr']['director']
                # od=1
                # for actor in showinfo[0]['cast']:
                    # thumbnail = ''
                    # if actor['i_t'] is not None:
                        # thumbnail = str('images.zattic.com/cms/' + actor['i_t'] +'/format_480x360.jpg')
                    # cast.append(xbmc.Actor(actor['f_n'],actor['c_n'],od,thumbnail))
                    # od = od+1
                # vinfo.setCast(cast)
                # vinfo.setGenres(showinfo[0]['g'])
                # vinfo.setDuration(rec['duration'])
                # #vinfo.setResumePoint(rec['start'])
                # vinfo.setDirectors(director)
                # if showinfo[0]['s_no'] is not None:
                    # vinfo.setSeason(showinfo[0]['s_no'])
                # if showinfo[0]['e_no'] is not None:
                    # vinfo.setEpisode(showinfo[0]['e_no'])
                # vinfo.setUniqueIDs({'tvdb':rec['cid'], 'imdb':rec['showID']})
                # #vinfo.setResumePoint(0, rec['duration'])
                # #li.setProperty('StartTime',str(rec['start']))
                # #li.setProperty('EndTime',str(rec['end']))
                # image = showinfo[0]['i_url']
            # if record['stream'] != 'False':
            
                # if record['key']:
                    # li.setProperty('inputstream', 'inputstream.adaptive')
                    # li.setProperty('inputstream.adaptive.manifest_type', 'mpd')
                    # li.setProperty('inputstream.adaptive.license_key', record['key'] + "||a{SSM}|")
                    # li.setProperty('inputstream.adaptive.license_type', "com.widevine.alpha")
                # else:
                    # li.setProperty('inputstream', 'inputstream.adaptive')
                    # li.setProperty('inputstream.adaptive.manifest_type', 'mpd')

    # li.setArt({'icon': logo, 'thumb': logo, 'poster': image, 'banner': image})
    # li.setProperty('Fanart_Image', image)
    # li.setProperty('IsPlayable', playable)
    # li.select(record['selected'])

    # # context menu
    # contextMenuItems = []
    # contextMenuItems.append(('Info', 'Action(Info)'))
    # if record['url2'] !='':
       # contextMenuItems.append((localString(31301), 'RunPlugin('+str(record['url2'])+')') )
    # if localString(31107) in record['title']:
       # contextMenuItems.append((localString(31023), 'RunPlugin(plugin://plugin.video.zattoo_hiq/?mode=reloadDB)'))
    # li.addContextMenuItems(contextMenuItems, replaceItems=True)
    # #debug(rec['url'])
    # xbmcplugin.addDirectoryItem(
        # handle=__addonhandle__,
        # url=record['url'], 
        # listitem=li, 
        # isFolder=record['isFolder']
        # )
    
  # xbmcplugin.setContent(__addonhandle__, con)
  # xbmcplugin.setPluginFanart(__addonhandle__, FANART_IMG)
  # xbmcplugin.endOfDirectory(__addonhandle__, succeeded=True, updateListing=root, cacheToDisc=False)

  #if con == 'tvshows':
  #      th = threading.Thread(target=container_refresh)
  #      th.start()
  #      makeZattooGUI()
  
# def build_root():
  # import urllib.request, urllib.parse, urllib.error

  # # check if settings are set
  # name = __addon__.getSetting('username')
  # if name == '':
    # # show home window, zattooHiQ settings and quit
    # xbmc.executebuiltin('ActivateWindow(10000)')
    # xbmcgui.Dialog().ok(__addonname__, localString(31902))
    # __addon__.openSettings()
    # sys.exit()

  # #play channel on open addon
  # if ((xbmcgui.Window(10000).getProperty('ZBEplayOnStart')!='false') and (not xbmc.Player().isPlaying()) and (__addon__.getSetting('start_liveTV')=='true')):
    # channeltitle = __addon__.getSetting('start_channel')
    # if channeltitle=="lastChannel":
        # channelid=_zattooDB_.get_playing()['channel']
    # elif channeltitle == "":
        # channelid = _zattooDB_.get_firstchan()
    # else:
        # channelid = _zattooDB_.get_channelid(channeltitle)
    # prog = _zattooDB_.getPrograms({'index': [channelid]})
    # showID = prog[0]['showID']
    # url = "plugin://"+__addonId__+"/?mode=watch_c&id=" + channelid + '&showID=' + showID
    # debug(url)
    # xbmc.executebuiltin('RunPlugin('+url+')')
    # xbmcgui.Window(10000).setProperty('ZBEplayOnStart', 'false')

# #  if _listMode_ == 'all': listTitle = localString(31100)
  # iconPath = __addon__.getAddonInfo('path') + '/resources/icon.png'
  # if _listMode_ == 'all': listTitle = localString(31100)
  # else: listTitle = localString(31101)
# #  if _listMode_ == 'all': listTitle = localString(31100)
  # RecLimit = __addon__.getSetting('record')
  # content = [

    # {'title': '[COLOR ff00ff00]'+localString(31099)+'[/COLOR]', 'image': POPULAR_IMG, 'thumbnail': POPULAR_IMG, 'isFolder': False, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'popular'})},
    # {'title': localString(31103), 'image': PREVIEW_IMG, 'thumbnail': PREVIEW_IMG, 'isFolder': False, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'preview'})},
    # {'title': localString(31104), 'image': EPG_IMG, 'thumbnail': EPG_IMG, 'isFolder': False, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'epg'})},
    # {'title': localString(31102), 'image': LIST_IMG, 'thumbnail': LIST_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'channellist'})},
    # {'title': localString(31105), 'image': SEARCH_IMG, 'thumbnail': SEARCH_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'searchlist', })},
  # ]
  # if VOD:
    # content.append({'title': localString(31109), 'image': VOD_IMG, 'thumbnail': VOD_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'vod',})},)
  # if RECORD:
    # content.append({'title': localString(31106) + ' ' + RecLimit, 'image': RECORD_IMG, 'thumbnail': RECORD_IMG,'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'recordings'})},)
  # content.append({'title': localString(31108), 'image': KAT_IMG, 'thumbnail': KAT_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'category'})},)

  # if __addon__.getSetting('help') == "true":
    # content.append({'title': '[COLOR yellow]'+local(10043)+'[/COLOR]', 'image': HELP_IMG, 'thumbnail': HELP_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'showhelp'})})
  # if __addon__.getSetting('settings') == "true":
    # content.append({'title': '[COLOR yellow]'+localString(31107)+' '+__addonname__+' - v.'+VERSION+'[/COLOR]', 'image': SETTING_IMG, 'thumbnail': SETTING_IMG, 'isFolder': False, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'show_settings'})})

  # build_directoryContent(content, True, False, 'files')


# def build_searchList():
  # import urllib.request, urllib.parse, urllib.error
  # #__addonuri__= sys.argv[0]
  # #__addonhandle__ = int(sys.argv[1])
  # search = _zattooDB_.get_search()
  # debug('Search '+str(search))


  # if search is not None:
        # xbmcplugin.addDirectoryItem(
          # handle=__addonhandle__,
          # url=__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'inputsearch'}),
          # listitem=xbmcgui.ListItem('[B][COLOR blue]' + localString(320000) +'[/B][/COLOR]'),
          # isFolder=True
        # )
        # xbmcplugin.addDirectoryItem(
          # handle=__addonhandle__,
          # url=__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'deletesearch', 'al': True, 'search': '_'}),
          # listitem=xbmcgui.ListItem('[B][COLOR blue]' + localString(320001) +'[/B][/COLOR]'),
          # isFolder=True
        # )
        # for chan in search['index']:
            # debug(chan)
            # #li = xbmcgui.ListItem(search[chan]['id'])
            # li = xbmcgui.ListItem(chan)
            # contextMenuItems = []
            # contextMenuItems.append((localString(320002), 'RunPlugin("plugin://'+__addonId__+'/?mode=deletesearch&al=False&search='+str(chan)+'")'))
            # contextMenuItems.append((localString(320003), 'RunPlugin("plugin://'+__addonId__+'/?mode=editsearch&search='+str(chan)+'")'))
            # li.addContextMenuItems(contextMenuItems, replaceItems=True)
            # xbmcplugin.addDirectoryItem(
              # handle=__addonhandle__,
              # url=__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'search', 'id': str(chan)}),
              # listitem=li,
              # isFolder=True
            # )


  # xbmcplugin.setContent(__addonhandle__, 'movies')
  # xbmcplugin.addSortMethod(__addonhandle__, xbmcplugin.SORT_METHOD_LABEL)
  # xbmcplugin.endOfDirectory(__addonhandle__, succeeded=True, updateListing=True, cacheToDisc=False)


# def build_channelsList():
  # global __addonuri__, _listMode_ 
  # __addonuri__ = 'plugin://plugin.video.zattoo_hiq/'

  # #import urllib.request, urllib.parse, urllib.error
  # channels = _zattooDB_.getChannelList(_listMode_ == 'favourites')
  # li = False
  # nr=0
  # for chan in channels['index']:
    # nr+=1
  # if channels is not None:
    # # get currently playing shows
    # if __addon__.getSetting('dbonstart') == 'true': li = True
    # program = _zattooDB_.getPrograms(channels)
    # content = []
    # # time of chanellist creation
    # if _listMode_ == 'favourites':
      # content.append({'title': '[B][COLOR blue]' + 'Favourites ('+str(nr)+')' +'[/B][/COLOR]', 'isFolder': True, 'url': __addonuri__ + '?' + urllib.parse.urlencode({'mode': 'switchlist'})})
    # else:
      # content.append({'title': '[B][COLOR blue]' + 'All ('+str(nr)+')' +'[/B][/COLOR]', 'isFolder': True, 'url':__addonuri__ + '?' + urllib.parse.urlencode({'mode': 'switchlist'})})
     
    # # get last watched channel
    # playing = _zattooDB_.get_playing()

    # nr=1
    # for chan in channels['index']:
        # #prog=program[chan]
        # prog = {}
        # for search in program:
            # if search['channel'] == chan:
              # prog = search
              # break
        # try:
            # start = prog.get('start_date','').strftime('%H:%M')
            # end = prog.get('end_date','').strftime('%H:%M')
            # startend = '[COLOR yellow]'+start+"-"+end+'[/COLOR]'
            # zstart = int(time.mktime(prog.get('start_date', '').timetuple()))
            # zend = int(time.mktime(prog.get('end_date', '').timetuple()))
        # except AttributeError:
            # startend = ''
        # if len(str(nr)) == 1:
            # chnr = '  '+str(nr)
        # else: chnr = str(nr)
        # # get url
        # streams = _zattooDB_.get_streams(chan, False)
        # if streams['streams'] == 'False':
            # url = "__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'watch_c', 'id': channels[chan]['id'], 'showID': prog.get('showID', '')}),"
            # stream = 'False'
        # else:            
            # stream = streams['streams']
            # url = streams['url']
        # if type(prog.get('restart','')) == str: continue
        # #debug(RECALL)
        # if RESTART and datetime.datetime.now() < prog.get('restart',''):
            # url2 = "plugin://"+__addonId__+"/?mode=watch_c&id=" + prog.get('channel', '') +'&showID=' + prog.get('showID','') + '&restart=true'
        # elif RECALL:
            # url2 = "plugin://"+__addonId__+"/?mode=watch_c&id=" + prog.get('channel', '') +'&showID=' + prog.get('showID','') + '&restart=true'
        # else: url2=''
        # showInfo = _zattooDB_.getShowInfo(prog.get('showID'))
        # if showInfo == 'NONE': 
            # showInfo = _zattooDB_.getShowInfo(prog.get('showID'))
        # if showInfo == 'NONE': showInfo = []
            
        # content.append({
            # 'title': '[COLOR lime]'+chnr+'[/COLOR]'+'  '+channels[chan]['title'] + ' - ' + prog.get('title', '')+ '  '+startend,
            # 'isFolder': False,            
            # 'url': url,
            # 'key': streams['key'],
            # 'url2': url2,
            # 'selected' : channels[chan]['id'] == playing['channel'],
            # 'duration': zend - zstart,
            # 'start': zstart,
            # 'end': zend,
            # 'showinfo': showInfo,
            # 'playable': 'true',
            # 'header': False,
            # 'stream': stream,
            # 'cid': chan,
            # 'showID': prog['showID'],
            # 'logo':channels[chan]['logo']
                            
        # })
        # nr+=1
        
  # build_directoryContent(content, False, False, 'tvshows')

# def build_category(cat):
  # #import urllib.request, urllib.parse, urllib.error

  # program = _zattooDB_.get_category(cat)
  # #debug('Progkategorien: '+str(program))
  # if program is not None:
    # channels = _zattooDB_.getChannelList(False)
    # #debug('KatChannels: '+str(channels))
    # content = []
    # # time of chanellist creation
    # content.append({'title': '[B][COLOR blue]' + cat +'[/B][/COLOR]', 'isFolder': True, 'url':__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'category'})})

    # # get last watched channel
    # playing = _zattooDB_.get_playing()

    # nr=1
    # for chan in program['index']:
      # #prog=program[chan]
      # # prog = {}
      # # for search in channels['index']:
        # # if search == chan:
          # # prog = search
          # # break
      # #debug(str(program[chan]))
      # try:
        # start = program[chan]['start_date'].strftime('%H:%M')
        # end = program[chan]['end_date'].strftime('%H:%M')
        # startend = '[COLOR yellow]'+start+"-"+end+'[/COLOR]'
        # zend = int(program[chan]['end_date'].strftime('%S'))
        # zstart = int(program[chan]['start_date'].strftime('%S'))

      # except AttributeError:
        # startend = ''
      # # get url
      # streams = _zattooDB_.get_streams(chan, False)
      # if streams['streams'] == 'False':
        # url = "__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'watch_c', 'id': channels[chan]['id'], 'showID': prog.get('showID', '')}),"
        # stream = 'False'
      # else:            
        # stream = streams['streams']
        # url = streams['url']
      # if len(str(nr)) == 1:
        # chnr = '  '+str(nr)
      # else: chnr = str(nr)

      # if RESTART and datetime.datetime.now() < program[chan]['restart']:
        # url2 = "plugin://"+__addonId__+"/?mode=watch_c&id=" + program[chan]['channel'] +'&showID=' + program[chan]['showID'] + '&restart=true'
      # elif RECALL:
        # url2 = "plugin://"+__addonId__+"/?mode=watch_c&id=" + program[chan]['channel'] +'&showID=' + program[chan]['showID'] + '&restart=true'
      # else: url2=''
      # showInfo = _zattooDB_.getShowInfo(program[chan]['showID'])
      # if showInfo == 'NONE': 
        # showInfo = _zattooDB_.getShowInfo(program[chan]['showID'])
      # debug(showInfo)
      # content.append({
        # 'title': '[COLOR green]'+chnr+'[/COLOR]'+'  '+channels[chan]['title'] + ' - ' + program[chan]['title']+ '  '+startend,
        # 'isFolder': False,
        # 'key': streams['key'],
        # 'url': url,
        # #'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'watch_c', 'id': channels[chan]['id'], 'showID': program[chan]['showID']}),
        # 'url2': url2,
        # 'selected' : channels[chan]['id'] == playing['channel'],
        # 'duration': zend - zstart,
        # 'showinfo': showInfo,
        # 'playable': 'true',
        # 'header': False,
        # 'stream': stream,
        # 'showID': program[chan]['showID'],
        # 'logo':channels[chan]['logo'],
        # 'cid': chan
      # })
      # nr+=1

  # build_directoryContent(content, False, False, 'tvshows')

# def build_recordingsList():
  # import urllib.request, urllib.parse, urllib.error

  # resultData = _zattooDB_.zapi.exec_zapiCall('/zapi/playlist', None)
  # debug('recordliste: '+str(resultData))
  # if resultData is None: return

  # for record in resultData['recordings']:
    # showInfo=_zattooDB_.getShowInfo(record['program_id'])
    # if not showInfo: continue
    # if showInfo == "NONE": continue
    # #mark if show is future, running or finished

    # start = int(time.mktime(time.strptime(record['start'], "%Y-%m-%dT%H:%M:%SZ"))) + _timezone_  # local timestamp
    # end = int(time.mktime(time.strptime(record['end'], "%Y-%m-%dT%H:%M:%SZ"))) + _timezone_  # local timestamp
    # position = int(time.mktime(time.strptime(record['position'], "%Y-%m-%dT%H:%M:%SZ"))) + _timezone_  # local timestamp
    # st = showInfo[0]['s']

    # now = time.time()
    # duration = end - start
    # color='crimson'

    # if (now>start): color='gold'
    # if (now>end): color='lime'

    # if RECREADY == "true":
        # if RECNOW == "false":
          # if color == "gold": continue
        # if color == "crimson": continue

    # if __addon__.getSetting('rec_name') == '0':
        # label=datetime.datetime.fromtimestamp(st).strftime('%Y.%m.%d. %H:%M')+' '
    # elif __addon__.getSetting('rec_name') == '1':
        # label=datetime.datetime.fromtimestamp(st).strftime('%a %d.%m.%Y. %H:%M')+' '
    # if record['episode_title']:
      # label+='[COLOR '+color+']'+record['title']+'[/COLOR]: '+record['episode_title']
      # title=record['title']+': '+record['episode_title']
     # # meta = {'title':record['episode_title'], 'tvshowtitle':record['title']}
    # else:
      # label+='[COLOR '+color+']'+record['title']+'[/COLOR]'
      # title=record['title']
     # # meta = {'title':record['title']}
    # if showInfo == "NONE": continue
    # label+=' ('+showInfo[0]['channel_name']+')'

    # director = []
    # cast = []

    # if showInfo[0]['cr'] != []:
        # director = showInfo[0]['cr']['director']
        # od=1
    # for actor in showInfo[0]['cast']:
        # if actor['i_t'] is not None:
            # thumbnail = str('images.zattic.com/cms/' + actor['i_t'] +'/format_480x360.jpg')
        # cast.append(xbmc.Actor(actor['f_n'],actor['c_n'],od,thumbnail))
        # od = od+1

    # country = [showInfo[0]['country']]

    # date = datetime.datetime.fromtimestamp(start).strftime('%d.%m.%Y')
    # li = xbmcgui.ListItem(label)
    # vinfo = li.getVideoInfoTag()
    # vinfo.setResumePoint(position-start+300, end-start)
    # vinfo.setTitle(label)
    # vinfo.setYear(showInfo[0]['year'])
    # vinfo.setPlot(showInfo[0]['d'])
    # vinfo.setCountries(country)
    # vinfo.setDirectors(director)
    # vinfo.setCast(cast)
    # vinfo.setGenres(showInfo[0]['g'])
    # vinfo.setDuration(showInfo[0]['e'] - showInfo[0]['s'])
    # vinfo.setSortTitle(record['title'])

    # '''
    # #mark watched
    # if (position>end-660):  #10min padding from zattoo +1min safety margin
        # meta.update({'overlay':7, 'playcount':12})
    # '''

    # if record['image_token'] is not None:
      # image_url = 'https://images.zattic.com/cms/' + record['image_token'] + '/format_480x360.jpg'
      # li.setArt({'thumb':image_url, 'fanart':image_url, 'landscape':image_url})
    # li.setProperty('IsPlayable', 'true')
    # li.setProperty('zStartTime', str(start))

    # try:
      # series=record['tv_series_id']
    # except:
      # seriesrec = 'None'

    # try:
      # if resultData['recorded_tv_series']:
        # for ser in resultData['recorded_tv_series']:
          # if series == ser['tv_series_id']:
            # seriesrec = 'true'
            # #debug('SeriesID '+str(series))
            # break
          # else:
            # seriesrec = 'None'
    # except:
      # seriesrec = 'None'

    # contextMenuItems = []
    # contextMenuItems.append(('Info', 'Action(Info)'))
    # contextMenuItems.append((localString(31926), 'Action(ToggleWatched)'))
    # if seriesrec == 'true':
      # contextMenuItems.append((localString(31925),'RunPlugin("plugin://'+__addonId__+'/?mode=remove_series&recording_id='+str(record['id'])+'&series='+str(series)+'")',))
    # contextMenuItems.append((localString(31921), 'RunPlugin("plugin://'+__addonId__+'/?mode=remove_recording&recording_id='+str(record['id'])+'&title='+str(title)+'")'))
    # li.addContextMenuItems(contextMenuItems, replaceItems=True)

    # xbmcplugin.addDirectoryItem(
      # handle=__addonhandle__,
      # url=__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'watch_r', 'id': record['id'], 'cid': record['cid'], 'start': start}),
      # listitem=li,
      # isFolder=False
    # )
  
  # xbmcplugin.setContent(__addonhandle__, 'movies')
  # xbmcplugin.addSortMethod(__addonhandle__, xbmcplugin.SORT_METHOD_LABEL)
  # xbmcplugin.addSortMethod(__addonhandle__, xbmcplugin.SORT_METHOD_DATE)
  # xbmcplugin.addSortMethod(__addonhandle__, xbmcplugin.SORT_METHOD_VIDEO_SORT_TITLE)
  # xbmcplugin.addSortMethod(__addonhandle__, xbmcplugin.SORT_METHOD_GENRE)
  # xbmcplugin.endOfDirectory(__addonhandle__, succeeded=True, cacheToDisc=False)
  
def watch_recording(recording_id, cid, start=0):
  #if xbmc.Player().isPlaying(): return

  if start == 0:
    startTime=int(xbmc.getInfoLabel('ListItem.Property(zStartTime)'))

  else:
    startTime=int(start)

  # drm = _zattooDB_.get_drm(cid)
  # if drm:
      # stream_type = 'dash_widevine'
  # else:
  stream_type = 'dash'
  params = {'stream_type': stream_type, 'enable_eac3':DOLBY, 'youth_protection_pin': YPIN}
  resultData = _zattooDB_.zapi.exec_zapiCall('/zapi/watch/recording/' + recording_id, params)
  debug ('ResultData: '+str(resultData))
  if resultData is not None:
    streams = resultData['stream']['watch_urls']

    li = xbmcgui.ListItem(path=streams[0]['url'])

    if stream_type == 'dash':
        li.setProperty('inputstream', 'inputstream.adaptive')
        li.setProperty('inputstream.adaptive.manifest_type', 'mpd')

    elif stream_type == 'dash_widevine':
        li.setProperty('inputstream', 'inputstream.adaptive')
        li.setProperty('inputstream.adaptive.manifest_type', 'mpd')
        li.setProperty('inputstream.adaptive.license_type', "com.widevine.alpha")
#        li.setProperty('inputstream.adaptive.stream_headers', 'xUser-Agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:109.0) Gecko/20100101 Firefox/109.0')
        li.setProperty('inputstream.adaptive.license_key', streams[1]['license_url'] + "||a{SSM}|")

    xbmcplugin.setResolvedUrl(__addonhandle__, True, li)
    pos=0
    xbmc.sleep(200)
    player=xbmc.Player()
    while (player.isPlaying()):
        try: pos=player.getTime()
        except: pass
        xbmc.sleep(100)

    #send watched position to zattoo
    #zStoptime=datetime.datetime.fromtimestamp(startTime+round(pos)-300).strftime("%Y-%m-%dT%H:%M:%SZ")

    zStoptime=datetime.datetime.fromtimestamp(startTime+round(pos)-300 - _timezone_ ).strftime("%Y-%m-%dT%H:%M:%SZ")
    resultData = _zattooDB_.zapi.exec_zapiCall('/zapi/playlist/recording', {'recording_id': recording_id, 'position': zStoptime})
    xbmc.executebuiltin('Container.Refresh')
    debug(resultData)

def setup_recording(program_id):
  #print('RECORDING: '+program_id)
  params = {'program_id': program_id}
  # test ob Aufnahme existiert
  playlist = _zattooDB_.zapi.exec_zapiCall('/zapi/playlist', None)
  for record in playlist['recordings']:
      if int(params['program_id']) == int(record['program_id']):
          xbmcgui.Dialog().ok(__addonname__, __addon__.getLocalizedString(31906))
          return

  resultData = _zattooDB_.zapi.exec_zapiCall('/zapi/playlist/program', params)

  debug('Recording: '+str(params)+'  '+str(resultData))

  if resultData is not None:
    xbmcgui.Dialog().ok(__addonname__, __addon__.getLocalizedString(31903) + '\n'+ __addon__.getLocalizedString(31904))
  else:
    xbmcgui.Dialog().ok(__addonname__, __addon__.getLocalizedString(31905))

  _library_.make_library()  # NEW added - by Samoth


def delete_recording(recording_id, title):
  dialog = xbmcgui.Dialog()
  ret = dialog.yesno(local(19112), str(title) + "\n" + '[COLOR gold]' + localString(32025)+'[/COLOR]' + '\n' + localString(32026) + '\n \n'+'[COLOR red]'+local(19291)+'[/COLOR]')
  if ret ==1:
    params = {'recording_id': recording_id}
    folder=__addon__.getSetting('library_dir') # NEW added - by Samoth
    if folder: # NEW added - by Samoth
      _library_.delete_entry_from_library(str(recording_id)) # NEW added - by Samoth
    resultData = _zattooDB_.zapi.exec_zapiCall('/zapi/playlist/remove', params)
    xbmc.executebuiltin('Container.Refresh')
# times in local timestamps

def delete_series(recording_id, series):
  dialog = xbmcgui.Dialog()
  params = {'recording_id': recording_id, 'tv_series_id':series, 'remove_recording':'true'}
  folder=__addon__.getSetting('library_dir') # NEW added - by Samoth
  if folder: # NEW added - by Samoth
    _library_.delete_entry_from_library(str(recording_id)) # NEW added - by Samoth
  resultData = _zattooDB_.zapi.exec_zapiCall('/zapi/series_recording/remove', params)
  xbmc.executebuiltin('Container.Refresh')

def slugify(value):
    """
    Normalizes string, converts to lowercase, removes non-alpha characters,
    and converts spaces to hyphens.
    """
    import re, unicodedata
    value = unicodedata.normalize('NFKD', value).encode('ascii', 'ignore')
    value = str(re.sub('[^\w\s-]', '', value).strip().lower())
    value = str(re.sub('[-\s]+', '-', value))
    return value


# def change_stream(dir):
  # playing = _zattooDB_.get_playing()
  # streams = playing['streams'].split('|')
  # streamNr = (playing['current_stream'] + dir) % len(streams)

  # _zattooDB_.set_currentStream(streamNr)

  # channelInfo = _zattooDB_.get_channelInfo(playing['channel'])
  # channel_id=_zattooDB_.get_playing()['channel']
  # program = _zattooDB_.getPrograms({'index':[channel_id]}, True)[0]

  # title = channelInfo['title'] + " (stream" + str(streamNr) + ")"
  # listitem = xbmcgui.ListItem(channelInfo['title'], thumbnailImage=channelInfo['logo'])
  # listitem.setInfo('video', {'Title': title, 'plot':program['description_long']})

  # xbmc.Player().play(streams[streamNr], listitem)
  # xbmcgui.Dialog().notification(title.translate(_umlaut_), program['title'].translate(_umlaut_), channelInfo['logo'], 5000, False)

def search_show(search):
  import urllib.request, urllib.parse, urllib.error
  debug(search)
  s = urllib.parse.quote(search)
  resultData = _zattooDB_.zapi.exec_zapiCall('/zapi/program/search?query=' + s, None)

  debug('Suche: '+str(resultData))
  _zattooDB_.set_search(search)
  if resultData is None:
    build_directoryContent([{'title': __addon__.getLocalizedString(31203), 'isFolder': False, 'url':''}])
    return

  programs = sorted(resultData['programs'], key=lambda prog: ( prog['start'], prog['cid']))

  channels = _zattooDB_.getChannelList(False)

  recall_shows = []
  record_shows = []
  now = int(to_seconds(datetime.datetime.now()))
  #debug(now)
  for program in programs:
    showID = program['id']
    debug(program)
    start = int(time.mktime(time.strptime(program['start'], "%Y-%m-%dT%H:%M:%SZ"))) + _timezone_  # local timestamp
    end = int(time.mktime(time.strptime(program['end'], "%Y-%m-%dT%H:%M:%SZ"))) + _timezone_  # local timestamp

    if program.get('episode_title', '') is not None:episode_title=program.get('episode_title', '')
    else:episode_title=''

    try:
        ry_u = int(time.mktime(time.strptime(program['replay_until'], "%Y-%m-%dT%H:%M:%SZ"))) + _timezone_
    except:
        ry_u = 0

    try:
      if not channels[program['cid']]:
        debug ('suche: '+str(program.get['cid']))
    except KeyError: continue

    showInfo = _zattooDB_.getShowInfo(showID)
    if showInfo == 'NONE': 
        showInfo = _zattooDB_.getShowInfo(showID)
    if showInfo == 'NONE': showInfo = []    

    # if info == 'NONE': continue
    # startInfo = _zattooDB_.get_showID(str(showID))
    # if startInfo == None: continue
    st = datetime.datetime.fromtimestamp(showInfo[0]['s'])

    #debug('ShowID: '+str(showID)+'  '+str(info))
    cred=''
    director=[]
    cast=[]
    credjson = program.get('credits','')
    if credjson is not None:
        try:
          cred = json.loads(credjson)
          debug (cred)
          director=cred['director']
          cast=cred['actor']
        except:pass
    if program.get('image_token') is not None:
      thumbnail = 'https://images.zattic.com/cms/' + program.get('image_token') + '/format_480x360.jpg'
    else:
      thumbnail = channels[program['cid']]['logo']

    item = {
        'title': '[COLOR yellow]' + st.strftime('%d.%m. ') + formatTime(st) + '[/COLOR] ' + '[COLOR lime]' + program.get('channel_name', '') + '[/COLOR]' + ': ' + program.get('title', '') + ' - ' + episode_title,
        'image': channels[program['cid']]['logo'],
        'thumbnail': thumbnail,
        'showinfo': showInfo,
        'stream': 'False',
        'duration': end - start,
        'start': start,
        'end': end,
        'header': False,
        'cid': str(program['cid']),
        'showID': str(showID),
        'isFolder': False
      }
    rec = {
        'title': '[COLOR yellow]'  + st.strftime('%d.%m. ') + formatTime(st)  + '[/COLOR] ' + '[COLOR lime]' + program.get('channel_name', '') + '[/COLOR]' + ': ' + program.get('title', '') + ' - ' + episode_title,
        'image': channels[program['cid']]['logo'],
        'thumbnail': thumbnail,
        'stream': 'False',
        'duration': end - start,
        'start': start,
        'end': end,
        'showinfo': showInfo,
        'header': False,
        'cid': str(program['cid']),
        'showID': str(showID),
        'isFolder': False
      }

    if start < now and ry_u > now:
        item['url'] = __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'watch_c', 'id': program['cid'], 'showID':showID, 'restart': 'true'})
        recall_shows.append(item)
        if RECORD:
          rec['url'] = __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'record_p', 'program_id': program['id']})
          record_shows.append(rec)
    elif start < now and end > now:
          item['url'] = __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'watch_c', 'id': program['cid'], 'showID':showID})
          recall_shows.append(item)
    elif start > now:
        if RECORD:
          rec['url'] = __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'record_p', 'program_id': program['id']})
          record_shows.append(rec)

  content = []
  if recall_shows != []:
    content.append({'title': '[B][COLOR blue]' + __addon__.getLocalizedString(31201) + '[/B][/COLOR]', 'isFolder': False, 'url':''})
    for item in recall_shows: content.append(item)
  if record_shows !=[]:
    content.append({'title': '[B][COLOR blue]' + __addon__.getLocalizedString(31202) + '[/B][/COLOR]', 'isFolder': False, 'url':''})
    for rec in record_shows: content.append(rec)
  if record_shows == [] and recall_shows ==[]:
    content.append({'title': __addon__.getLocalizedString(31203), 'isFolder': False, 'url':''})
  build_directoryContent(content, True, False,'tvshows')


def showPreview(popularList=''):
  xbmc.executebuiltin("Dialog.Close(all, true)")
  from .channelspreview import ChannelsPreview
  preview = ChannelsPreview()
  if popularList=='popular': preview.createPreview('popular')
  else: preview.createPreview(_listMode_ == 'favourites')
  preview.show() #doModal()
  while xbmcgui.Window(10000).getProperty('zattoo_runningView')=="preview": xbmc.sleep(10)
  del preview

def showHelp():
  import urllib
  iconPath = __addon__.getAddonInfo('path') + '/icon.png'
  content = [
    {'title': '[COLOR blue]'+local(10043)+'[/COLOR]', 'url':__addonuri__+ '?' + urllib.parse.urlencode({'mode': 'showhelp'}), 'image': HELP_IMG, 'isFolder': True, },
    {'title': local(128), 'image': ICON_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'helpmy', 'img':'main.png'})},
    {'title': localString(30300), 'image': ICON_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'helpmy', 'img':'Live-Keymap.png'})},
    {'title': 'EPG', 'image': EPG_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'helpmy', 'img':'epg-1.png'})},
    {'title': 'EPG - Touchscreen', 'image': EPG_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'helpmy', 'img':'epg-2.png'})},
    {'title': local(10550), 'image': ICON_IMG, 'isFolder': True, 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'helpmy', 'img':'Teletext.png'})},


  ]
  build_directoryContent(content, True, False, 'files')

def selectStartChannel():
  channels = _zattooDB_.getChannelList(_listMode_ == 'favourites')
  chanList = [localString(310095)]
  for chan in channels['index']: chanList.append(channels[chan]['title'])
  dialog=xbmcgui.Dialog()
  ret = dialog.select(localString(31009), chanList)
  if ret==-1: return
  __addon__.setSetting('start_liveTV', 'true')
  if ret==0: __addon__.setSetting('start_channel', 'lastChannel')
  else: __addon__.setSetting('start_channel', chanList[ret])

# def showCategory():
    
    # cat = _zattooDB_.set_category()
    # #debug('Kategorien: '+str(cat))

    # content = []

    # for record in cat:
      # content.append(
      # {
        # 'title':record['category']+' ('+str(record['len'])+')',
        # 'image': ICON_IMG,
        # 'isFolder': True,
        # 'url': __addonuri__+ '?' + urllib.parse.urlencode({'mode': 'build_category', 'cat': record['category']})
      # })

    # build_directoryContent(content, False )


    

    


